/***************************************
 *                                     *
 *  JBoss: The OpenSource J2EE WebOS   *
 *                                     *
 *  Distributable under LGPL license.  *
 *  See terms of license at gnu.org.   *
 *                                     *
 ***************************************/

package org.jboss.repositoryselectorexample;

import java.io.*;
import java.net.*;

import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * This servlet demonstrates initialization of a RepositorySelector so that
 * logging can be done on a per-app basis.
 *
 * @author  Stan Silvert
 */
public class Log4JServlet extends HttpServlet {
    
    private static Logger LOG;
    
    private String servletName;
    private MyObject myObj; // can't initialize until init() method called
    
    /** Initializes the servlet.
     */
    public void init(ServletConfig config) throws ServletException {
        super.init(config);
        this.servletName = config.getServletName();
        
        
        MyRepositorySelector.init(config);
        
        // note that we can't call Logger.getLogger() until 
        // MyRepositorySelector.init() is called.  For all other classes in the 
        // webapp, you can call Logger.getLogger() at any time.
        this.LOG = Logger.getLogger(Log4JServlet.class);
        
        // the same goes for the Logger.getLogger() method in MyObject
        this.myObj = new MyObject(this.servletName);
    }
    
    /** Destroys the servlet.
     */
    public void destroy() {
        MyRepositorySelector.removeFromRepository();
    }
    
    /** 
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code> 
     * methods.
     * @param request servlet request
     * @param response servlet response
     */
    protected void processRequest(HttpServletRequest request, 
                                  HttpServletResponse response)
            throws ServletException, IOException {
        
        response.setContentType("text/html");
        PrintWriter out = response.getWriter();
        out.println("<html>");
        out.println("<head>");
        out.println("<title>Servlet</title>");
        out.println("</head>");
        out.println("<body>");
        out.println("Here is some output");
        LOG.error("TEST FROM THE SERVLET: " + this.servletName);
        myObj.foo();
        out.println("</body>");
        out.println("</html>");
        out.close();
    }
    
    /** Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     */
    protected void doGet(HttpServletRequest request, 
                         HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }
    
    /** Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     */
    protected void doPost(HttpServletRequest request, 
                          HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }
    
    /** Returns a short description of the servlet.
     */
    public String getServletInfo() {
        return "Log4JServlet";
    }
    
}
